4.41. umbra.ui.delegates — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.41. umbra.ui.delegates

delegates.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the Application Delegates classes.

Others:

## 4.41.1. Module Attributes

`umbra.ui.delegates.` `LOGGER`

## 4.41.2. Classes

class `umbra.ui.delegates.` `Style`(**kwargs)

  Bases: `foundations.dataStructures.Structure`

  This class represents a storage object for the `RichText_QStyledItemDelegate` class style.

  Parameters: | **kwargs – . ( Key / Value pairs )

class `umbra.ui.delegates.` `RichText_QStyledItemDelegate`(parent=None, style=None, highlightColor=None, hoverColor=None, backgroundColor=None, highlightBackgroundColor=None, hoverBackgroundColor=None)

  Bases: `PyQt4.QtGui.QStyledItemDelegate`

  This class is a QStyledItemDelegate subclass used as a rich text Delegate for Application Views.

  Parameters: | parent – Widget parent. ( QObject ) style – Style. ( Style )

  `style`

    This method is the property for self.__style attribute.

    Returns: | self.__style. ( Style )

  `paint`(painter, option, index)

    This method reimplements the `QStyledItemDelegate.paint()` method.

  `sizeHint`(option, index)

    This method reimplements the `QStyledItemDelegate.sizeHint()` method.

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »